@@ -39,6 +39,7 @@
 #include <ThreadWeaver/Queue>
 #include <ThreadWeaver/Thread>
 
+#include "dbusrunner_p.h"
 #include "runnerjobs_p.h"
 #include "plasma/pluginloader.h"
 #include <plasma/version.h>
@@ -62,8 +63,8 @@ public:
 
     RunnerManagerPrivate(RunnerManager *parent)
       : q(parent),
-        deferredRun(0),
-        currentSingleRunner(0),
+        deferredRun(nullptr),
+        currentSingleRunner(nullptr),
         prepped(false),
         allRunnersPrepped(false),
         singleRunnerPrepped(false),
@@ -129,7 +130,7 @@ public:
             delete currentSingleRunner;
         }
 
-        currentSingleRunner = 0;
+        currentSingleRunner = nullptr;
     }
 
     void loadSingleRunner()
@@ -154,7 +155,7 @@ public:
             return;
         }
 
-        KService::List offers = KServiceTypeTrader::self()->query("Plasma/Runner", QString("[X-KDE-PluginInfo-Name] == '%1'").arg(singleModeRunnerId));
+        KService::List offers = KServiceTypeTrader::self()->query(QStringLiteral("Plasma/Runner"), QStringLiteral("[X-KDE-PluginInfo-Name] == '%1'").arg(singleModeRunnerId));
         if (!offers.isEmpty()) {
             const KService::Ptr &service = offers[0];
             currentSingleRunner = loadInstalledRunner(service);
@@ -190,7 +191,7 @@ public:
             KPluginInfo &description = it.next();
             qCDebug(KRUNNER) << "Loading runner: " << description.pluginName();
 
-            QString tryExec = description.property("TryExec").toString();
+            QString tryExec = description.property(QStringLiteral("TryExec")).toString();
             if (!tryExec.isEmpty() && QStandardPaths::findExecutable(tryExec).isEmpty()) {
                 // we don't actually have this application!
                 continue;
@@ -202,14 +203,14 @@ public:
             const bool loaded = runners.contains(runnerName);
             const bool selected = loadAll || (description.isPluginEnabled() && (noWhiteList || whiteList.contains(runnerName)));
 
-            const bool singleQueryModeEnabled = description.property("X-Plasma-AdvertiseSingleRunnerQueryMode").toBool();
+            const bool singleQueryModeEnabled = description.property(QStringLiteral("X-Plasma-AdvertiseSingleRunnerQueryMode")).toBool();
 
             if (singleQueryModeEnabled) {
                 advertiseSingleRunnerIds.insert(runnerName, description.name());
             }
 
             if (selected) {
-                AbstractRunner *runner = 0;
+                AbstractRunner *runner = nullptr;
                 if (!loaded) {
                     runner = loadInstalledRunner(description.service());
                 } else {
@@ -293,12 +294,12 @@ public:
     AbstractRunner *loadInstalledRunner(const KService::Ptr service)
     {
         if (!service) {
-            return 0;
+            return nullptr;
         }
 
-        AbstractRunner *runner = 0;
+        AbstractRunner *runner = nullptr;
 
-        const QString api = service->property("X-Plasma-API").toString();
+        const QString api = service->property(QStringLiteral("X-Plasma-API")).toString();
 
         if (api.isEmpty()) {
             QVariantList args;
@@ -312,6 +313,8 @@ public:
 #endif
                 }
             }
+        } else if (api == QLatin1String("DBus")){
+            runner = new DBusRunner(service, q);
         } else {
             //qCDebug(KRUNNER) << "got a script runner known as" << api;
             runner = new AbstractRunner(service, q);
@@ -342,7 +345,7 @@ public:
         if (deferredRun.isEnabled() && runJob->runner() == deferredRun.runner()) {
             //qCDebug(KRUNNER) << "job actually done, running now **************";
             QueryMatch tmpRun = deferredRun;
-            deferredRun = QueryMatch(0);
+            deferredRun = QueryMatch(nullptr);
             tmpRun.run(context);
         }
 
@@ -667,7 +670,7 @@ void RunnerManager::run(const QueryMatch &match)
     }
 
     if (d->deferredRun.isValid()) {
-        d->deferredRun = QueryMatch(0);
+        d->deferredRun = QueryMatch(nullptr);
     }
 
     d->context.run(match);
@@ -696,13 +699,11 @@ QMimeData * RunnerManager::mimeDataForMatch(const QueryMatch &match) const
         return runner->mimeDataForMatch(match);
     }
 
-    return 0;
+    return nullptr;
 }
 
 KPluginInfo::List RunnerManager::listRunnerInfo(const QString &parentApp)
 {
-    KPluginInfo::List list;
-
     QString constraint;
     if (parentApp.isEmpty()) {
         constraint.append("not exist [X-KDE-ParentApp]");
@@ -710,8 +711,8 @@ KPluginInfo::List RunnerManager::listRunnerInfo(const QString &parentApp)
         constraint.append("[X-KDE-ParentApp] == '").append(parentApp).append("'");
     }
 
-    KService::List offers = KServiceTypeTrader::self()->query("Plasma/Runner", constraint);
-    return list + KPluginInfo::fromServices(offers);
+    KService::List offers = KServiceTypeTrader::self()->query(QStringLiteral("Plasma/Runner"), constraint);
+    return KPluginInfo::fromServices(offers);
 }
 
 void RunnerManager::setupMatchSession()
@@ -775,7 +776,7 @@ void RunnerManager::launchQuery(const QString &untrimmedTerm, const QString &run
 
     if (term.isEmpty()) {
         if (d->singleMode && d->currentSingleRunner->defaultSyntax()) {
-            term = d->currentSingleRunner->defaultSyntax()->exampleQueries().first().remove(QRegExp(":q:"));
+            term = d->currentSingleRunner->defaultSyntax()->exampleQueries().first().remove(QRegExp(QStringLiteral(":q:")));
         } else {
             reset();
             return;
@@ -840,7 +841,7 @@ void RunnerManager::reset()
     if (d->deferredRun.isEnabled()) {
         //qCDebug(KRUNNER) << "job actually done, running now **************";
         QueryMatch tmpRun = d->deferredRun;
-        d->deferredRun = QueryMatch(0);
+        d->deferredRun = QueryMatch(nullptr);
         tmpRun.run(d->context);
     }
 
